(**************************************************************)
(* APPL_POWER.MLI *)
(* Author: Mark Hayden, 12/98 *)
(**************************************************************)
open Trans

val newf : 'a Appl_intf.New.power -> Appl_intf.New.t
